@@ -6,15 +6,17 @@ use regex::Regex;
 lazy_static! {
     static ref ARGS: Vec<String> = std::env::args().skip(1).collect();
 }
+
 pub struct App {
     pub db: Database,
 }
 
 impl App {
-    pub fn new() -> Self {
+    pub fn run() {
         Self {
             db: Database::new(),
         }
+        .parse_args()
     }
     pub fn print_tasks(&self) {
         let total_tasks = self.db.total_tasks();
@@ -22,8 +24,7 @@ impl App {
         let total_notes = self.db.total_notes();
 
         if total_tasks == 0 {
-            ui::help_message();
-            return;
+            return ui::help_message();
         }
 
         let boards = self.db.get_boards();
@@ -51,6 +52,20 @@ impl App {
 
         ui::footer(total_checked, total_tasks, total_notes);
     }
+    fn print_old(&self) {
+        let old_tasks = self.db.get_old();
+        if old_tasks.is_empty() {
+            return println!("No old tasks.");
+        }
+
+        ui::clear();
+
+        ui::old_header();
+
+        for (i, task) in old_tasks.iter().enumerate() {
+            ui::note(i + 1, task, old_tasks.len());
+        }
+    }
     fn ids() -> Option<Vec<usize>> {
         let re = Regex::new("^[0-9 ]*$").unwrap();
 
@@ -83,6 +98,10 @@ impl App {
         let args = if is_note { &ARGS[1..] } else { &ARGS };
         let mut board_name = None;
 
+        if args.is_empty() {
+            panic!("this should not have happend?");
+        }
+
         let item = if args.len() >= 2 {
             if args[0].contains('!') {
                 //t !board 'task ...'
@@ -92,16 +111,20 @@ impl App {
                 //t 'long task ...'
                 args[0..].join(" ")
             }
-        } else if !args.is_empty() {
-            if args[0].contains('!') {
-                //t !board
+        } else if args[0].contains('!') {
+            let strs: Vec<&str> = args[0].split(' ').collect();
+
+            //t '!board'
+            if strs.len() == 1 {
                 panic!("Missing task!");
             } else {
-                //t 'task'
-                args[0..].join(" ")
+                //t '!board task ...'
+                board_name = Some(strs[0].replace('!', ""));
+                strs[1..].join(" ")
             }
         } else {
-            panic!("This should not have happend!");
+            //t 'task'
+            args[0..].join(" ")
         };
 
         if is_note {
@@ -112,43 +135,28 @@ impl App {
     }
     pub fn parse_args(&self) {
         match ARGS.len() {
-            0 => {
-                self.print_tasks();
-            }
-            _ => {
-                if ARGS.len() == 1 {
-                    if let "d" | "n" | "c" = ARGS[0].as_str() {
-                        println!("Missing arguments for '{}'", &ARGS[0]);
-                        return;
+            0 => self.print_tasks(),
+            _ => match ARGS[0].as_str() {
+                "n" | "d" if ARGS.len() == 1 => return ui::missing_args(ARGS[0].as_str()),
+                "h" | "help" => return ui::help(),
+                "v" | "version" => return println!("t {}", env!("CARGO_PKG_VERSION")),
+                "o" | "old" => return self.print_old(),
+                "n" => self.add(true),
+                "d" => {
+                    if let Some(ids) = App::ids() {
+                        self.db.delete_tasks(&ids);
                     }
                 }
-                match ARGS[0].as_str() {
-                    "h" | "help" | "--help" => {
-                        ui::help();
-                        return;
+                "cls" => self.db.clear_tasks().unwrap(),
+                _ => {
+                    if let Some(ids) = App::ids() {
+                        self.db.check_tasks(&ids);
+                    } else {
+                        self.add(false);
                     }
-                    "v" | "version" | "--version" => {
-                        println!("t {}", env!("CARGO_PKG_VERSION"));
-                        return;
-                    }
-                    "d" => {
-                        if let Some(ids) = App::ids() {
-                            self.db.delete_tasks(&ids);
-                        }
-                    }
-                    "cls" => self.db.clear_tasks().unwrap(),
-                    "n" => self.add(true),
-                    _ => {
-                        if let Some(ids) = App::ids() {
-                            self.db.check_tasks(&ids);
-                        } else {
-                            self.add(false);
-                        }
-                    }
-                };
-
-                self.print_tasks();
-            }
+                }
+            },
         }
+        self.print_tasks();
     }
 }
